# Generated by ariadne-codegen on 2023-06-06 10:50

from .air_quality_device_element_reads import (
    AirQualityDeviceElementReads,
    AirQualityDeviceElementReadsAirQualityDeviceElementReads,
)
from .air_quality_devices import (
    AirQualityDevices,
    AirQualityDevicesAirQualityDevices,
    AirQualityDevicesAirQualityDevicesLocation,
)
from .async_base_client import AsyncBaseClient
from .base_model import BaseModel
from .client import WorldAthletics
from .competition_document import (
    CompetitionDocument,
    CompetitionDocumentCompetitionDocument,
)
from .competitions_by_country import (
    CompetitionsByCountry,
    CompetitionsByCountryCompetitionsByCountry,
    CompetitionsByCountryCompetitionsByCountryParameters,
    CompetitionsByCountryCompetitionsByCountryResults,
)
from .countries_by_event_id import (
    CountriesByEventId,
    CountriesByEventIdCountriesByEventId,
)
from .current_record_holder import (
    CurrentRecordHolder,
    CurrentRecordHolderCurrentRecordHolder,
    CurrentRecordHolderCurrentRecordHolderCompetitor,
)
from .disciplines_by_event_id import (
    DisciplinesByEventId,
    DisciplinesByEventIdDisciplinesByEventId,
)
from .enums import (
    AirQualityDeviceFilter,
    CarouselTypeEnum,
    GenderType,
    MetaDataTypes,
    OrderByEnum,
    OrderByLiveBlogPostEnum,
    OrderByNewArticleEnum,
    OrderDirectionEnum,
    PlacingTableOrderBy,
    RelatedCompetitionEnum,
    TeamStandingOrderBy,
    eventPhaseOrderByEnum,
    medalsOrderByEnum,
)
from .event_media import (
    EventMedia,
    EventMediaEventMedia,
    EventMediaEventMediaMedia,
    EventMediaEventMediaQuery,
)
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQlClientInvalidResponseError,
)
from .get_all_competitions import (
    GetAllCompetitions,
    GetAllCompetitionsGetAllCompetitions,
    GetAllCompetitionsGetAllCompetitionsAllEvents,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageCampaign,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModules,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisite,
)
from .get_all_event_phases_by_discipline import (
    GetAllEventPhasesByDiscipline,
    GetAllEventPhasesByDisciplineGetAllEventPhasesByDiscipline,
    GetAllEventPhasesByDisciplineGetAllEventPhasesByDisciplineDiscipline,
)
from .get_all_gold_tour_events import (
    GetAllGoldTourEvents,
    GetAllGoldTourEventsGetAllGoldTourEvents,
    GetAllGoldTourEventsGetAllGoldTourEventsEvents,
)
from .get_all_time_list import (
    GetAllTimeList,
    GetAllTimeListGetAllTimeList,
    GetAllTimeListGetAllTimeListPayload,
)
from .get_appearance import (
    GetAppearance,
    GetAppearanceGetAppearance,
    GetAppearanceGetAppearanceDefaultSponsors,
    GetAppearanceGetAppearanceDefaultSponsorsDarkBgLogo,
    GetAppearanceGetAppearanceDefaultSponsorsLightBgLogo,
    GetAppearanceGetAppearanceFeatureImage,
    GetAppearanceGetAppearanceLogo,
    GetAppearanceGetAppearanceSponsors,
    GetAppearanceGetAppearanceSponsorsDarkBgLogo,
    GetAppearanceGetAppearanceSponsorsLightBgLogo,
)
from .get_article import (
    GetArticle,
    GetArticleGetArticle,
    GetArticleGetArticleLocation,
    GetArticleGetArticleRelatedArticles,
    GetArticleGetArticleRelatedArticlesLocation,
    GetArticleGetArticleRelatedArticlesRelatedArticles,
    GetArticleGetArticleRelatedArticlesRelatedArticlesLocation,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedCompetitions,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPage,
    GetArticleGetArticleRelatedArticlesRelatedCompetitors,
    GetArticleGetArticleRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedDiscipline,
    GetArticleGetArticleRelatedArticlesRelatedMedia,
    GetArticleGetArticleRelatedCompetitions,
    GetArticleGetArticleRelatedCompetitionsLastEvent,
    GetArticleGetArticleRelatedCompetitionsLastEventCircuits,
    GetArticleGetArticleRelatedCompetitionsLastEventPage,
    GetArticleGetArticleRelatedCompetitionsNextEvent,
    GetArticleGetArticleRelatedCompetitionsNextEventCircuits,
    GetArticleGetArticleRelatedCompetitionsNextEventPage,
    GetArticleGetArticleRelatedCompetitionsPage,
    GetArticleGetArticleRelatedCompetitionsPageCampaign,
    GetArticleGetArticleRelatedCompetitionsPageContentModules,
    GetArticleGetArticleRelatedCompetitionsPageEvent,
    GetArticleGetArticleRelatedCompetitionsPageMinisite,
    GetArticleGetArticleRelatedCompetitors,
    GetArticleGetArticleRelatedCompetitorsRelatedMedia,
    GetArticleGetArticleRelatedDiscipline,
    GetArticleGetArticleRelatedMedia,
)
from .get_article_locations import (
    GetArticleLocations,
    GetArticleLocationsGetArticleLocations,
)
from .get_articles import (
    GetArticles,
    GetArticlesGetArticles,
    GetArticlesGetArticlesLocation,
    GetArticlesGetArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesLocation,
    GetArticlesGetArticlesRelatedArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesLocation,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPage,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedArticlesRelatedMedia,
    GetArticlesGetArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedCompetitionsLastEvent,
    GetArticlesGetArticlesRelatedCompetitionsLastEventCircuits,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPage,
    GetArticlesGetArticlesRelatedCompetitionsNextEvent,
    GetArticlesGetArticlesRelatedCompetitionsNextEventCircuits,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPage,
    GetArticlesGetArticlesRelatedCompetitionsPage,
    GetArticlesGetArticlesRelatedCompetitionsPageCampaign,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModules,
    GetArticlesGetArticlesRelatedCompetitionsPageEvent,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisite,
    GetArticlesGetArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedCompetitorsRelatedMedia,
    GetArticlesGetArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedMedia,
)
from .get_asset import (
    GetAsset,
    GetAssetGetAsset,
    GetAssetGetAssetCampaign,
    GetAssetGetAssetDocument,
    GetAssetGetAssetFilters,
    GetAssetGetAssetFiltersType,
    GetAssetGetAssetFiltersTypeFilters,
    GetAssetGetAssetThumbnailFeatureImage,
)
from .get_assets import (
    GetAssets,
    GetAssetsGetAssets,
    GetAssetsGetAssetsCampaign,
    GetAssetsGetAssetsDocument,
    GetAssetsGetAssetsFilters,
    GetAssetsGetAssetsFiltersType,
    GetAssetsGetAssetsFiltersTypeFilters,
    GetAssetsGetAssetsThumbnailFeatureImage,
)
from .get_assets_dates import GetAssetsDates, GetAssetsDatesGetAssetsDates
from .get_assets_total import GetAssetsTotal, GetAssetsTotalGetAssetsTotal
from .get_athlete import (
    GetAthlete,
    GetAthleteGetAthlete,
    GetAthleteGetAthletePrimaryMedia,
)
from .get_athlete_profile_athlete_representative import (
    GetAthleteProfileAthleteRepresentative,
    GetAthleteProfileAthleteRepresentativeGetAthleteProfileAthleteRepresentative,
)
from .get_athlete_representative_athlete_search import (
    GetAthleteRepresentativeAthleteSearch,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearch,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletes,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletesChildren,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchCountries,
)
from .get_athlete_representative_directory import (
    GetAthleteRepresentativeDirectory,
    GetAthleteRepresentativeDirectoryGetAthleteRepresentativeDirectory,
)
from .get_athlete_representative_profile import (
    GetAthleteRepresentativeProfile,
    GetAthleteRepresentativeProfileGetAthleteRepresentativeProfile,
    GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplist,
    GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplistAthletes,
)
from .get_athlete_representative_top_list import (
    GetAthleteRepresentativeTopList,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopList,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEvents,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEventTypes,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListGenders,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplist,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplistAthletes,
)
from .get_athlete_results import (
    GetAthleteResults,
    GetAthleteResultsGetAthleteResults,
    GetAthleteResultsGetAthleteResultsTeamMembers,
)
from .get_banners import (
    GetBanners,
    GetBannersGetBanners,
    GetBannersGetBannersBannerItems,
    GetBannersGetBannersBannerItemsPrimaryMedia,
)
from .get_c_i_s_competitor_res_date import (
    GetCISCompetitorResDate,
    GetCISCompetitorResDateGetCISCompetitorResDate,
    GetCISCompetitorResDateGetCISCompetitorResDateParameters,
    GetCISCompetitorResDateGetCISCompetitorResDateResultsByDate,
)
from .get_c_i_s_competitor_res_disp import (
    GetCISCompetitorResDisp,
    GetCISCompetitorResDispGetCISCompetitorResDisp,
    GetCISCompetitorResDispGetCISCompetitorResDispParameters,
    GetCISCompetitorResDispGetCISCompetitorResDispResultsByDate,
    GetCISCompetitorResDispGetCISCompetitorResDispResultsByEvent,
    GetCISCompetitorResDispGetCISCompetitorResDispResultsByEventResults,
)
from .get_c_i_s_single_competitor import (
    GetCISSingleCompetitor,
    GetCISSingleCompetitorGetCISSingleCompetitor,
    GetCISSingleCompetitorGetCISSingleCompetitorAthleteRepresentative,
    GetCISSingleCompetitorGetCISSingleCompetitorBasicData,
    GetCISSingleCompetitorGetCISSingleCompetitorHonours,
    GetCISSingleCompetitorGetCISSingleCompetitorHonoursResults,
    GetCISSingleCompetitorGetCISSingleCompetitorPersonalBests,
    GetCISSingleCompetitorGetCISSingleCompetitorPersonalBestsResults,
    GetCISSingleCompetitorGetCISSingleCompetitorProgressionOfSeasonsBests,
    GetCISSingleCompetitorGetCISSingleCompetitorProgressionOfSeasonsBestsResults,
    GetCISSingleCompetitorGetCISSingleCompetitorResultsByDate,
    GetCISSingleCompetitorGetCISSingleCompetitorResultsByDateParameters,
    GetCISSingleCompetitorGetCISSingleCompetitorResultsByDateResultsByDate,
    GetCISSingleCompetitorGetCISSingleCompetitorResultsByYear,
    GetCISSingleCompetitorGetCISSingleCompetitorResultsByYearParameters,
    GetCISSingleCompetitorGetCISSingleCompetitorResultsByYearResultsByEvent,
    GetCISSingleCompetitorGetCISSingleCompetitorResultsByYearResultsByEventResults,
    GetCISSingleCompetitorGetCISSingleCompetitorRoadRaceLabelStatus,
    GetCISSingleCompetitorGetCISSingleCompetitorSeasonsBests,
    GetCISSingleCompetitorGetCISSingleCompetitorSeasonsBestsParameters,
    GetCISSingleCompetitorGetCISSingleCompetitorSeasonsBestsResults,
    GetCISSingleCompetitorGetCISSingleCompetitorWorldRankings,
    GetCISSingleCompetitorGetCISSingleCompetitorWorldRankingsBest,
    GetCISSingleCompetitorGetCISSingleCompetitorWorldRankingsCurrent,
    GetCISSingleCompetitorGetCISSingleCompetitorWorldRankingsParameters,
)
from .get_calendar_competition_results import (
    GetCalendarCompetitionResults,
    GetCalendarCompetitionResultsGetCalendarCompetitionResults,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters,
)
from .get_calendar_events import (
    GetCalendarEvents,
    GetCalendarEventsGetCalendarEvents,
    GetCalendarEventsGetCalendarEventsOptions,
    GetCalendarEventsGetCalendarEventsOptionsCompetitionGroups,
    GetCalendarEventsGetCalendarEventsOptionsCompetitionSubgroups,
    GetCalendarEventsGetCalendarEventsOptionsDisciplines,
    GetCalendarEventsGetCalendarEventsOptionsPermitLevels,
    GetCalendarEventsGetCalendarEventsOptionsRankingCategories,
    GetCalendarEventsGetCalendarEventsOptionsRegions,
    GetCalendarEventsGetCalendarEventsOptionsRegionsArea,
    GetCalendarEventsGetCalendarEventsOptionsRegionsCountry,
    GetCalendarEventsGetCalendarEventsOptionsRegionsWorld,
    GetCalendarEventsGetCalendarEventsOptionsSeasons,
    GetCalendarEventsGetCalendarEventsParameters,
    GetCalendarEventsGetCalendarEventsResults,
    GetCalendarEventsGetCalendarEventsResultsUndeterminedCompetitionPeriod,
)
from .get_campaign import GetCampaign, GetCampaignGetCampaign
from .get_campaigns import GetCampaigns, GetCampaignsGetCampaigns
from .get_carousel import (
    GetCarousel,
    GetCarouselGetCarousel,
    GetCarouselGetCarouselCarouselItems,
    GetCarouselGetCarouselCarouselItemsPrimaryMedia,
    GetCarouselGetCarouselMedia,
)
from .get_championship_highlights import (
    GetChampionshipHighlights,
    GetChampionshipHighlightsGetChampionshipHighlights,
    GetChampionshipHighlightsGetChampionshipHighlightsDays,
    GetChampionshipHighlightsGetChampionshipHighlightsRounds,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecords,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHead,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponents,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlights,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitors,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalists,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecords,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitor,
)
from .get_championship_qualifications import (
    GetChampionshipQualifications,
    GetChampionshipQualificationsGetChampionshipQualifications,
    GetChampionshipQualificationsGetChampionshipQualificationsAlternativeEntryStandards,
    GetChampionshipQualificationsGetChampionshipQualificationsCountries,
    GetChampionshipQualificationsGetChampionshipQualificationsEvents,
    GetChampionshipQualificationsGetChampionshipQualificationsQualifications,
    GetChampionshipQualificationsGetChampionshipQualificationsQualificationTypes,
)
from .get_combined_points import (
    GetCombinedPoints,
    GetCombinedPointsGetCombinedPoints,
    GetCombinedPointsGetCombinedPointsAllDisciplines,
    GetCombinedPointsGetCombinedPointsCompetitors,
    GetCombinedPointsGetCombinedPointsCompetitorsDisciplines,
)
from .get_competition_organiser_info import (
    GetCompetitionOrganiserInfo,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits,
)
from .get_competitor import GetCompetitor, GetCompetitorGetCompetitor
from .get_competitor_a_a_id import GetCompetitorAAId
from .get_competitors_legacy_primary_media import (
    GetCompetitorsLegacyPrimaryMedia,
    GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia,
)
from .get_countries import GetCountries, GetCountriesGetCountries
from .get_discipline import GetDiscipline, GetDisciplineGetDiscipline
from .get_drafted_article import (
    GetDraftedArticle,
    GetDraftedArticleGetDraftedArticle,
    GetDraftedArticleGetDraftedArticleContentModules,
    GetDraftedArticleGetDraftedArticleContentModulesLocations,
    GetDraftedArticleGetDraftedArticleContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleEvent,
    GetDraftedArticleGetDraftedArticleEventCircuits,
    GetDraftedArticleGetDraftedArticleEventPage,
    GetDraftedArticleGetDraftedArticleEventPageCampaign,
    GetDraftedArticleGetDraftedArticleEventPageContentModules,
    GetDraftedArticleGetDraftedArticleEventPageEvent,
    GetDraftedArticleGetDraftedArticleEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesCampaign,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsors,
)
from .get_event import (
    GetEvent,
    GetEventGetEvent,
    GetEventGetEventCircuits,
    GetEventGetEventRelatedMedia,
)
from .get_event_broken_records import (
    GetEventBrokenRecords,
    GetEventBrokenRecordsGetEventBrokenRecords,
    GetEventBrokenRecordsGetEventBrokenRecordsDiscipline,
)
from .get_event_circuit_standings import (
    GetEventCircuitStandings,
    GetEventCircuitStandingsGetEventCircuitStandings,
    GetEventCircuitStandingsGetEventCircuitStandingsParameters,
    GetEventCircuitStandingsGetEventCircuitStandingsStandings,
    GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntries,
    GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntriesResults,
)
from .get_event_leading_standings import (
    GetEventLeadingStandings,
    GetEventLeadingStandingsGetEventLeadingStandings,
    GetEventLeadingStandingsGetEventLeadingStandingsDiscipline,
)
from .get_event_phase_by_discipline import (
    GetEventPhaseByDiscipline,
    GetEventPhaseByDisciplineGetEventPhaseByDiscipline,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineDiscipline,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineDocuments,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummary,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummaryTeamMembers,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnits,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResults,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResultsTeamMembers,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeries,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeriesAttempts,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSplits,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlist,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlistTeamMembers,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandings,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandingsTeamMembers,
)
from .get_event_phase_result_detail import (
    GetEventPhaseResultDetail,
    GetEventPhaseResultDetailGetEventPhaseResultDetail,
    GetEventPhaseResultDetailGetEventPhaseResultDetailDiscipline,
    GetEventPhaseResultDetailGetEventPhaseResultDetailResult,
    GetEventPhaseResultDetailGetEventPhaseResultDetailResultDiscipline,
)
from .get_event_phase_results import (
    GetEventPhaseResults,
    GetEventPhaseResultsGetEventPhaseResults,
    GetEventPhaseResultsGetEventPhaseResultsDiscipline,
    GetEventPhaseResultsGetEventPhaseResultsResult,
    GetEventPhaseResultsGetEventPhaseResultsResultDiscipline,
)
from .get_event_phases import (
    GetEventPhases,
    GetEventPhasesGetEventPhases,
    GetEventPhasesGetEventPhasesDiscipline,
)
from .get_event_team_standing_details import (
    GetEventTeamStandingDetails,
    GetEventTeamStandingDetailsGetEventTeamStandingDetails,
    GetEventTeamStandingDetailsGetEventTeamStandingDetailsCompetitor,
    GetEventTeamStandingDetailsGetEventTeamStandingDetailsDiscipline,
)
from .get_event_team_standings import (
    GetEventTeamStandings,
    GetEventTeamStandingsGetEventTeamStandings,
)
from .get_event_timetable import (
    GetEventTimetable,
    GetEventTimetableGetEventTimetable,
    GetEventTimetableGetEventTimetableDiscipline,
)
from .get_events import (
    GetEvents,
    GetEventsGetEvents,
    GetEventsGetEventsCircuits,
    GetEventsGetEventsPage,
    GetEventsGetEventsPageCampaign,
    GetEventsGetEventsPageContentModules,
    GetEventsGetEventsPageContentModulesBanners,
    GetEventsGetEventsPageContentModulesFeatureLinks,
    GetEventsGetEventsPageContentModulesLifestyleLinks,
    GetEventsGetEventsPageContentModulesLocations,
    GetEventsGetEventsPageContentModulesMinisite,
    GetEventsGetEventsPageContentModulesMinisitePage,
    GetEventsGetEventsPageContentModulesRelatedArticles,
    GetEventsGetEventsPageContentModulesRelatedCompetitors,
    GetEventsGetEventsPageContentModulesRelatedDiscipline,
    GetEventsGetEventsPageContentModulesRelatedEvents,
    GetEventsGetEventsPageContentModulesRelatedMedia,
    GetEventsGetEventsPageContentModulesRelatedVideo,
    GetEventsGetEventsPageContentModulesRelatedVideos,
    GetEventsGetEventsPageContentModulesSections,
    GetEventsGetEventsPageContentModulesSlides,
    GetEventsGetEventsPageContentModulesVideos,
    GetEventsGetEventsPageEvent,
    GetEventsGetEventsPageEventCircuits,
    GetEventsGetEventsPageEventPage,
    GetEventsGetEventsPageMinisite,
    GetEventsGetEventsPageMinisiteDefaultSponsors,
    GetEventsGetEventsPageMinisiteFeatureImage,
    GetEventsGetEventsPageMinisiteLogo,
    GetEventsGetEventsPageMinisiteSponsors,
)
from .get_filter_types import (
    GetFilterTypes,
    GetFilterTypesGetFilterTypes,
    GetFilterTypesGetFilterTypesFilters,
    GetFilterTypesGetFilterTypesFiltersType,
    GetFilterTypesGetFilterTypesFiltersTypeFilters,
)
from .get_flash_interviews import (
    GetFlashInterviews,
    GetFlashInterviewsGetFlashInterviews,
    GetFlashInterviewsGetFlashInterviewsInterviews,
)
from .get_hero_athletes_carousel import (
    GetHeroAthletesCarousel,
    GetHeroAthletesCarouselGetHeroAthletesCarousel,
    GetHeroAthletesCarouselGetHeroAthletesCarouselRelatedMedia,
)
from .get_latest_qualified_competitors import (
    GetLatestQualifiedCompetitors,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitors,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsColumns,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualifications,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitor,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitorTeamMembers,
)
from .get_latest_records import (
    GetLatestRecords,
    GetLatestRecordsGetLatestRecords,
    GetLatestRecordsGetLatestRecordsRecords,
    GetLatestRecordsGetLatestRecordsRecordsCompetitor,
    GetLatestRecordsGetLatestRecordsRecordsCompetitorTeamMembers,
)
from .get_leading_athletes import (
    GetLeadingAthletes,
    GetLeadingAthletesGetLeadingAthletes,
    GetLeadingAthletesGetLeadingAthletesEventResults,
    GetLeadingAthletesGetLeadingAthletesEventResultsResults,
    GetLeadingAthletesGetLeadingAthletesEventResultsResultsCompetitor,
    GetLeadingAthletesGetLeadingAthletesEventResultsResultsPrimaryMedia,
)
from .get_live_blog_posts import GetLiveBlogPosts, GetLiveBlogPostsGetLiveBlogPosts
from .get_live_combined_summary_details import (
    GetLiveCombinedSummaryDetails,
    GetLiveCombinedSummaryDetailsGetLiveCombinedSummaryDetails,
)
from .get_live_phase_summary import (
    GetLivePhaseSummary,
    GetLivePhaseSummaryGetLivePhaseSummary,
)
from .get_live_result import (
    GetLiveResult,
    GetLiveResultGetLiveResult,
    GetLiveResultGetLiveResultTeamMembers,
)
from .get_medal import GetMedal, GetMedalGetMedal
from .get_medal_details import GetMedalDetails, GetMedalDetailsGetMedalDetails
from .get_medals import GetMedals, GetMedalsGetMedals, GetMedalsGetMedalsCountry
from .get_media import GetMedia, GetMediaGetMedia
from .get_medias import GetMedias, GetMediasGetMedias
from .get_meta_data import (
    GetMetaData,
    GetMetaDataGetMetaData,
    GetMetaDataGetMetaDataCountryCodes,
    GetMetaDataGetMetaDataDisciplineCodes,
)
from .get_minisite_calendar_events import (
    GetMinisiteCalendarEvents,
    GetMinisiteCalendarEventsGetMinisiteCalendarEvents,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptions,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionGroups,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionSubgroups,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsDisciplines,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsPermitLevels,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRankingCategories,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegions,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsArea,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsCountry,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsWorld,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsSeasons,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsParameters,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsResults,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsResultsUndeterminedCompetitionPeriod,
)
from .get_new_article import (
    GetNewArticle,
    GetNewArticleGetNewArticle,
    GetNewArticleGetNewArticleContentModules,
    GetNewArticleGetNewArticleContentModulesLocations,
    GetNewArticleGetNewArticleContentModulesLocationsLocation,
    GetNewArticleGetNewArticleContentModulesRelatedVideo,
    GetNewArticleGetNewArticleContentModulesRelatedVideos,
    GetNewArticleGetNewArticleEvent,
    GetNewArticleGetNewArticleEventCircuits,
    GetNewArticleGetNewArticleEventPage,
    GetNewArticleGetNewArticleEventPageCampaign,
    GetNewArticleGetNewArticleEventPageContentModules,
    GetNewArticleGetNewArticleEventPageEvent,
    GetNewArticleGetNewArticleEventPageMinisite,
    GetNewArticleGetNewArticleRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedArticlesEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticleGetNewArticleRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPage,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPage,
    GetNewArticleGetNewArticleRelatedCompetitionsPage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageCampaign,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModules,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisite,
    GetNewArticleGetNewArticleRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedEvents,
    GetNewArticleGetNewArticleRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedEventsPageCampaign,
    GetNewArticleGetNewArticleRelatedEventsPageContentModules,
    GetNewArticleGetNewArticleRelatedEventsPageEvent,
    GetNewArticleGetNewArticleRelatedEventsPageMinisite,
    GetNewArticleGetNewArticleRelatedLinks,
    GetNewArticleGetNewArticleRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedMinisitePagesCampaign,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBanners,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSections,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSlides,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventCircuits,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsors,
)
from .get_new_articles import (
    GetNewArticles,
    GetNewArticlesGetNewArticles,
    GetNewArticlesGetNewArticlesContentModules,
    GetNewArticlesGetNewArticlesContentModulesLocations,
    GetNewArticlesGetNewArticlesContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesEvent,
    GetNewArticlesGetNewArticlesEventCircuits,
    GetNewArticlesGetNewArticlesEventPage,
    GetNewArticlesGetNewArticlesEventPageCampaign,
    GetNewArticlesGetNewArticlesEventPageContentModules,
    GetNewArticlesGetNewArticlesEventPageEvent,
    GetNewArticlesGetNewArticlesEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedEventsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedEventsPageEvent,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesCampaign,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsors,
)
from .get_new_medias import GetNewMedias, GetNewMediasGetNewMedias
from .get_news_ticker import GetNewsTicker, GetNewsTickerGetNewsTicker
from .get_on_this_day import (
    GetOnThisDay,
    GetOnThisDayGetOnThisDay,
    GetOnThisDayGetOnThisDayResults,
)
from .get_page import (
    GetPage,
    GetPageGetPage,
    GetPageGetPageCampaign,
    GetPageGetPageContentModules,
    GetPageGetPageContentModulesBanners,
    GetPageGetPageContentModulesBannersPage,
    GetPageGetPageContentModulesFeatureLinks,
    GetPageGetPageContentModulesLifestyleLinks,
    GetPageGetPageContentModulesLocations,
    GetPageGetPageContentModulesLocationsLocation,
    GetPageGetPageContentModulesMinisite,
    GetPageGetPageContentModulesMinisiteDefaultSponsors,
    GetPageGetPageContentModulesMinisiteFeatureImage,
    GetPageGetPageContentModulesMinisiteLogo,
    GetPageGetPageContentModulesMinisitePage,
    GetPageGetPageContentModulesMinisitePageCampaign,
    GetPageGetPageContentModulesMinisitePageContentModules,
    GetPageGetPageContentModulesMinisitePageEvent,
    GetPageGetPageContentModulesMinisitePageMinisite,
    GetPageGetPageContentModulesMinisiteSponsors,
    GetPageGetPageContentModulesRelatedArticles,
    GetPageGetPageContentModulesRelatedArticlesContentModules,
    GetPageGetPageContentModulesRelatedArticlesEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticles,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitions,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedArticlesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedEvents,
    GetPageGetPageContentModulesRelatedArticlesRelatedLinks,
    GetPageGetPageContentModulesRelatedArticlesRelatedMedia,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetPageGetPageContentModulesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetPageGetPageContentModulesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedEvents,
    GetPageGetPageContentModulesRelatedEventsCircuits,
    GetPageGetPageContentModulesRelatedEventsPage,
    GetPageGetPageContentModulesRelatedMedia,
    GetPageGetPageContentModulesRelatedVideo,
    GetPageGetPageContentModulesRelatedVideos,
    GetPageGetPageContentModulesSections,
    GetPageGetPageContentModulesSectionsLinks,
    GetPageGetPageContentModulesSlides,
    GetPageGetPageContentModulesVideos,
    GetPageGetPageContentModulesVideosThumbnailImage,
    GetPageGetPageEvent,
    GetPageGetPageEventCircuits,
    GetPageGetPageEventPage,
    GetPageGetPageEventPageCampaign,
    GetPageGetPageEventPageContentModules,
    GetPageGetPageEventPageEvent,
    GetPageGetPageEventPageMinisite,
    GetPageGetPageMinisite,
    GetPageGetPageMinisiteDefaultSponsors,
    GetPageGetPageMinisiteDefaultSponsorsDarkBgLogo,
    GetPageGetPageMinisiteDefaultSponsorsLightBgLogo,
    GetPageGetPageMinisiteFeatureImage,
    GetPageGetPageMinisiteLogo,
    GetPageGetPageMinisiteSponsors,
    GetPageGetPageMinisiteSponsorsDarkBgLogo,
    GetPageGetPageMinisiteSponsorsLightBgLogo,
)
from .get_phases import GetPhases, GetPhasesGetPhases, GetPhasesGetPhasesUnits
from .get_placing_table import GetPlacingTable, GetPlacingTableGetPlacingTable
from .get_placing_table_details import (
    GetPlacingTableDetails,
    GetPlacingTableDetailsGetPlacingTableDetails,
)
from .get_pre_championship_highlights import (
    GetPreChampionshipHighlights,
    GetPreChampionshipHighlightsGetPreChampionshipHighlights,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEvents,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeaders,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampions,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeaders,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembers,
)
from .get_random_world_ranking_discipline import (
    GetRandomWorldRankingDiscipline,
    GetRandomWorldRankingDisciplineGetRandomWorldRankingDiscipline,
    GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineQuery,
    GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineRankings,
)
from .get_ranking_groups import (
    GetRankingGroups,
    GetRankingGroupsGetRankingGroups,
    GetRankingGroupsGetRankingGroupsEvents,
)
from .get_ranking_score_calculation import (
    GetRankingScoreCalculation,
    GetRankingScoreCalculationGetRankingScoreCalculation,
    GetRankingScoreCalculationGetRankingScoreCalculationResults,
)
from .get_recent_results import (
    GetRecentResults,
    GetRecentResultsGetRecentResults,
    GetRecentResultsGetRecentResultsResults,
    GetRecentResultsGetRecentResultsResultsEvent,
    GetRecentResultsGetRecentResultsResultsEventCircuits,
    GetRecentResultsGetRecentResultsResultsEventPage,
)
from .get_records_by_category import (
    GetRecordsByCategory,
    GetRecordsByCategoryGetRecordsByCategory,
    GetRecordsByCategoryGetRecordsByCategoryCompetitor,
)
from .get_records_disciplines import (
    GetRecordsDisciplines,
    GetRecordsDisciplinesGetRecordsDisciplines,
)
from .get_result_info import GetResultInfo, GetResultInfoGetResultInfo
from .get_single_competitor import (
    GetSingleCompetitor,
    GetSingleCompetitorGetSingleCompetitor,
    GetSingleCompetitorGetSingleCompetitorAthleteRepresentative,
    GetSingleCompetitorGetSingleCompetitorBasicData,
    GetSingleCompetitorGetSingleCompetitorBasicDataPrimaryMedia,
    GetSingleCompetitorGetSingleCompetitorHonours,
    GetSingleCompetitorGetSingleCompetitorHonoursResults,
    GetSingleCompetitorGetSingleCompetitorPersonalBests,
    GetSingleCompetitorGetSingleCompetitorPersonalBestsResults,
    GetSingleCompetitorGetSingleCompetitorPrimaryMedia,
    GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBests,
    GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBestsResults,
    GetSingleCompetitorGetSingleCompetitorResultsByDate,
    GetSingleCompetitorGetSingleCompetitorResultsByDateParameters,
    GetSingleCompetitorGetSingleCompetitorResultsByDateResultsByDate,
    GetSingleCompetitorGetSingleCompetitorResultsByYear,
    GetSingleCompetitorGetSingleCompetitorResultsByYearParameters,
    GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEvent,
    GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEventResults,
    GetSingleCompetitorGetSingleCompetitorSeasonsBests,
    GetSingleCompetitorGetSingleCompetitorSeasonsBestsParameters,
    GetSingleCompetitorGetSingleCompetitorSeasonsBestsResults,
    GetSingleCompetitorGetSingleCompetitorWorldRankings,
    GetSingleCompetitorGetSingleCompetitorWorldRankingsBest,
    GetSingleCompetitorGetSingleCompetitorWorldRankingsCurrent,
    GetSingleCompetitorGetSingleCompetitorWorldRankingsParameters,
)
from .get_single_competitor_all_time_personal_top10 import (
    GetSingleCompetitorAllTimePersonalTop10,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Disciplines,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Parameters,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Results,
)
from .get_single_competitor_honour_summary import (
    GetSingleCompetitorHonourSummary,
    GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary,
)
from .get_single_competitor_major_championships import (
    GetSingleCompetitorMajorChampionships,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionships,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsParameters,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResults,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResultsResults,
)
from .get_single_competitor_results_by_limit import (
    GetSingleCompetitorResultsByLimit,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimit,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitDisciplines,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitParameters,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitResults,
)
from .get_single_competitor_results_date import (
    GetSingleCompetitorResultsDate,
    GetSingleCompetitorResultsDateGetSingleCompetitorResultsDate,
    GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateParameters,
    GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateResultsByDate,
)
from .get_single_competitor_results_discipline import (
    GetSingleCompetitorResultsDiscipline,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDiscipline,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineParameters,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByDate,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEvent,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEventResults,
)
from .get_single_competitor_season_bests import (
    GetSingleCompetitorSeasonBests,
    GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBests,
    GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsParameters,
    GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsResults,
)
from .get_single_competitor_winning_streak import (
    GetSingleCompetitorWinningStreak,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreak,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakDisciplineOptions,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakParameters,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaks,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaksResults,
)
from .get_social_carousel import (
    GetSocialCarousel,
    GetSocialCarouselGetSocialCarousel,
    GetSocialCarouselGetSocialCarouselPrimaryMedia,
)
from .get_spikes import (
    GetSpikes,
    GetSpikesGetSpikes,
    GetSpikesGetSpikesPrimaryMedia,
    GetSpikesGetSpikesRelatedTags,
)
from .get_team_results import (
    GetTeamResults,
    GetTeamResultsGetTeamResults,
    GetTeamResultsGetTeamResultsTeamMembers,
)
from .get_team_scoring import (
    GetTeamScoring,
    GetTeamScoringGetTeamScoring,
    GetTeamScoringGetTeamScoringAthlete,
    GetTeamScoringGetTeamScoringAthleteDetail,
)
from .get_top_list import GetTopList, GetTopListGetTopList, GetTopListGetTopListPayload
from .get_top_lists_disciplines import (
    GetTopListsDisciplines,
    GetTopListsDisciplinesGetTopListsDisciplines,
)
from .get_top_rankings import (
    GetTopRankings,
    GetTopRankingsGetTopRankings,
    GetTopRankingsGetTopRankingsRankings,
    GetTopRankingsGetTopRankingsRankingsPrimaryMedia,
)
from .get_trending_athletes import (
    GetTrendingAthletes,
    GetTrendingAthletesGetTrendingAthletes,
    GetTrendingAthletesGetTrendingAthletesAthletesList,
    GetTrendingAthletesGetTrendingAthletesAthletesListPrimaryMedia,
    GetTrendingAthletesGetTrendingAthletesPrimaryMedia,
)
from .get_upcoming_competitions import (
    GetUpcomingCompetitions,
    GetUpcomingCompetitionsGetUpcomingCompetitions,
    GetUpcomingCompetitionsGetUpcomingCompetitionsCompetitions,
)
from .get_user import GetUser, GetUserGetUser, GetUserGetUserSettings
from .get_users_votes import GetUsersVotes, GetUsersVotesGetUsersVotes
from .get_verification import GetVerification, GetVerificationGetVerification
from .get_video_by_id import GetVideoById, GetVideoByIdGetVideoById
from .get_video_list import GetVideoList, GetVideoListGetVideoList
from .get_video_playlist import GetVideoPlaylist, GetVideoPlaylistGetVideoPlaylist
from .get_videos_total_number import (
    GetVideosTotalNumber,
    GetVideosTotalNumberGetVideosTotalNumber,
)
from .get_vocabulary import GetVocabulary, GetVocabularyGetVocabulary
from .get_vote_options import GetVoteOptions, GetVoteOptionsGetVoteOptions
from .get_waw_competition import (
    GetWawCompetition,
    GetWawCompetitionGetWawCompetition,
    GetWawCompetitionGetWawCompetitionLastEvent,
    GetWawCompetitionGetWawCompetitionLastEventCircuits,
    GetWawCompetitionGetWawCompetitionLastEventPage,
    GetWawCompetitionGetWawCompetitionLastEventPageCampaign,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModules,
    GetWawCompetitionGetWawCompetitionLastEventPageEvent,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisite,
    GetWawCompetitionGetWawCompetitionNextEvent,
    GetWawCompetitionGetWawCompetitionNextEventCircuits,
    GetWawCompetitionGetWawCompetitionNextEventPage,
    GetWawCompetitionGetWawCompetitionNextEventPageCampaign,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModules,
    GetWawCompetitionGetWawCompetitionNextEventPageEvent,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisite,
    GetWawCompetitionGetWawCompetitionPage,
    GetWawCompetitionGetWawCompetitionPageCampaign,
    GetWawCompetitionGetWawCompetitionPageContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesBanners,
    GetWawCompetitionGetWawCompetitionPageContentModulesFeatureLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesLifestyleLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesLocations,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisite,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePage,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticles,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEvents,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedMedia,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideo,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideos,
    GetWawCompetitionGetWawCompetitionPageContentModulesSections,
    GetWawCompetitionGetWawCompetitionPageContentModulesSlides,
    GetWawCompetitionGetWawCompetitionPageContentModulesVideos,
    GetWawCompetitionGetWawCompetitionPageEvent,
    GetWawCompetitionGetWawCompetitionPageEventCircuits,
    GetWawCompetitionGetWawCompetitionPageEventPage,
    GetWawCompetitionGetWawCompetitionPageMinisite,
    GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionPageMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionPageMinisiteLogo,
    GetWawCompetitionGetWawCompetitionPageMinisiteSponsors,
)
from .get_waw_competition_events_organizer_details import (
    GetWawCompetitionEventsOrganizerDetails,
    GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails,
    GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails,
)
from .get_waw_event import (
    GetWawEvent,
    GetWawEventGetWawEvent,
    GetWawEventGetWawEventCircuits,
    GetWawEventGetWawEventPage,
    GetWawEventGetWawEventPageCampaign,
    GetWawEventGetWawEventPageContentModules,
    GetWawEventGetWawEventPageContentModulesBanners,
    GetWawEventGetWawEventPageContentModulesFeatureLinks,
    GetWawEventGetWawEventPageContentModulesLifestyleLinks,
    GetWawEventGetWawEventPageContentModulesLocations,
    GetWawEventGetWawEventPageContentModulesMinisite,
    GetWawEventGetWawEventPageContentModulesMinisitePage,
    GetWawEventGetWawEventPageContentModulesRelatedArticles,
    GetWawEventGetWawEventPageContentModulesRelatedCompetitors,
    GetWawEventGetWawEventPageContentModulesRelatedDiscipline,
    GetWawEventGetWawEventPageContentModulesRelatedEvents,
    GetWawEventGetWawEventPageContentModulesRelatedMedia,
    GetWawEventGetWawEventPageContentModulesRelatedVideo,
    GetWawEventGetWawEventPageContentModulesRelatedVideos,
    GetWawEventGetWawEventPageContentModulesSections,
    GetWawEventGetWawEventPageContentModulesSlides,
    GetWawEventGetWawEventPageContentModulesVideos,
    GetWawEventGetWawEventPageEvent,
    GetWawEventGetWawEventPageEventCircuits,
    GetWawEventGetWawEventPageEventPage,
    GetWawEventGetWawEventPageMinisite,
    GetWawEventGetWawEventPageMinisiteDefaultSponsors,
    GetWawEventGetWawEventPageMinisiteFeatureImage,
    GetWawEventGetWawEventPageMinisiteLogo,
    GetWawEventGetWawEventPageMinisiteSponsors,
)
from .get_waw_event_country_list import (
    GetWawEventCountryList,
    GetWawEventCountryListGetWawEventCountryList,
    GetWawEventCountryListGetWawEventCountryListCountries,
)
from .get_waw_medal_details import (
    GetWawMedalDetails,
    GetWawMedalDetailsGetWawMedalDetails,
    GetWawMedalDetailsGetWawMedalDetailsCompetitor,
    GetWawMedalDetailsGetWawMedalDetailsDiscipline,
)
from .get_waw_menu import (
    GetWawMenu,
    GetWawMenuGetWawMenu,
    GetWawMenuGetWawMenuEvent,
    GetWawMenuGetWawMenuEventCircuits,
    GetWawMenuGetWawMenuEventPage,
    GetWawMenuGetWawMenuEventPageCampaign,
    GetWawMenuGetWawMenuEventPageContentModules,
    GetWawMenuGetWawMenuEventPageEvent,
    GetWawMenuGetWawMenuEventPageMinisite,
    GetWawMenuGetWawMenuItems,
    GetWawMenuGetWawMenuItemsItems,
    GetWawMenuGetWawMenuItemsItemsItems,
    GetWawMenuGetWawMenuItemsItemsPage,
    GetWawMenuGetWawMenuItemsPage,
    GetWawMenuGetWawMenuItemsPageCampaign,
    GetWawMenuGetWawMenuItemsPageContentModules,
    GetWawMenuGetWawMenuItemsPageEvent,
    GetWawMenuGetWawMenuItemsPageMinisite,
)
from .get_waw_placing_table_details import (
    GetWawPlacingTableDetails,
    GetWawPlacingTableDetailsGetWawPlacingTableDetails,
    GetWawPlacingTableDetailsGetWawPlacingTableDetailsCompetitor,
    GetWawPlacingTableDetailsGetWawPlacingTableDetailsDiscipline,
)
from .get_waw_placing_tables import (
    GetWawPlacingTables,
    GetWawPlacingTablesGetWawPlacingTables,
)
from .get_world_leading_competitors import (
    GetWorldLeadingCompetitors,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitors,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResults,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResults,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitor,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsPrimaryMedia,
)
from .get_world_ranking import GetWorldRanking, GetWorldRankingGetWorldRanking
from .get_world_rankings import (
    GetWorldRankings,
    GetWorldRankingsGetWorldRankings,
    GetWorldRankingsGetWorldRankingsParameters,
    GetWorldRankingsGetWorldRankingsRankings,
)
from .get_world_rankings_changes import (
    GetWorldRankingsChanges,
    GetWorldRankingsChangesGetWorldRankingsChanges,
    GetWorldRankingsChangesGetWorldRankingsChangesChanges,
)
from .head_to_head import (
    HeadToHead,
    HeadToHeadHeadToHead,
    HeadToHeadHeadToHeadDisciplines,
    HeadToHeadHeadToHeadOpponents,
    HeadToHeadHeadToHeadParameters,
    HeadToHeadHeadToHeadResults,
    HeadToHeadHeadToHeadResultsResults,
)
from .input_types import (
    AAapiQuery,
    ChunkType,
    ClientMetadataInput,
    CompetitorInput,
    CompetitorQueryInput,
    EventInput,
    FlashInterviewInput,
    LiveCombinedSummaryDetailInput,
    LivePhaseSummaryInput,
    LivePhaseSummaryQuery,
    LiveResultInput,
    LiveResultTeamMemberInput,
    MedalDetailInput,
    MedalInput,
    MedalMutationInput,
    PhaseInput,
    PhaseQueryInput,
    PlacingTableDetailInput,
    PlacingTableInput,
    PreviousMedalQuery,
    TeamQuery,
    TeamScoringInput,
    TeamStandingsInput,
    UnitInput,
)
from .my_athletes import (
    MyAthletes,
    MyAthletesMyAthletes,
    MyAthletesMyAthletesPrimaryMedia,
)
from .previous_medalists import PreviousMedalists, PreviousMedalistsPreviousMedalists
from .records_by_event import (
    RecordsByEvent,
    RecordsByEventRecordsByEvent,
    RecordsByEventRecordsByEventCompetitor,
)
from .results_by_athlete import (
    ResultsByAthlete,
    ResultsByAthleteResultsByAthlete,
    ResultsByAthleteResultsByAthleteParameters,
    ResultsByAthleteResultsByAthleteResults,
    ResultsByAthleteResultsByAthleteResultsAthlete,
)
from .search_athletes import (
    SearchAthletes,
    SearchAthletesSearchAthletes,
    SearchAthletesSearchAthletesCompetitionEntries,
    SearchAthletesSearchAthletesCompetitionEntriesDiscipline,
    SearchAthletesSearchAthletesDisciplines,
    SearchAthletesSearchAthletesPrimaryMedia,
)
from .search_competitors import SearchCompetitors, SearchCompetitorsSearchCompetitors
from .team_profile import (
    TeamProfile,
    TeamProfileTeamProfile,
    TeamProfileTeamProfilePersonalBestInfo,
    TeamProfileTeamProfilePersonalBests,
    TeamProfileTeamProfilePersonalBestsDiscipline,
    TeamProfileTeamProfilePersonalHonour,
    TeamProfileTeamProfilePersonalHonourDiscipline,
    TeamProfileTeamProfilePersonalHonourInfo,
)
from .team_standings import (
    TeamStandings,
    TeamStandingsTeamStandings,
    TeamStandingsTeamStandingsRelatedAthlete,
    TeamStandingsTeamStandingsRelatedAthleteDetail,
)
from .verify_captcha_token import (
    VerifyCaptchaToken,
    VerifyCaptchaTokenVerifyCaptchaToken,
)
from .verify_h_captcha_token import (
    VerifyHCaptchaToken,
    VerifyHCaptchaTokenVerifyHCaptchaToken,
)

__all__ = [
    "AAapiQuery",
    "AirQualityDeviceElementReads",
    "AirQualityDeviceElementReadsAirQualityDeviceElementReads",
    "AirQualityDeviceFilter",
    "AirQualityDevices",
    "AirQualityDevicesAirQualityDevices",
    "AirQualityDevicesAirQualityDevicesLocation",
    "AsyncBaseClient",
    "BaseModel",
    "CarouselTypeEnum",
    "ChunkType",
    "ClientMetadataInput",
    "CompetitionDocument",
    "CompetitionDocumentCompetitionDocument",
    "CompetitionsByCountry",
    "CompetitionsByCountryCompetitionsByCountry",
    "CompetitionsByCountryCompetitionsByCountryParameters",
    "CompetitionsByCountryCompetitionsByCountryResults",
    "CompetitorInput",
    "CompetitorQueryInput",
    "CountriesByEventId",
    "CountriesByEventIdCountriesByEventId",
    "CurrentRecordHolder",
    "CurrentRecordHolderCurrentRecordHolder",
    "CurrentRecordHolderCurrentRecordHolderCompetitor",
    "DisciplinesByEventId",
    "DisciplinesByEventIdDisciplinesByEventId",
    "EventInput",
    "EventMedia",
    "EventMediaEventMedia",
    "EventMediaEventMediaMedia",
    "EventMediaEventMediaQuery",
    "FlashInterviewInput",
    "GenderType",
    "GetAllCompetitions",
    "GetAllCompetitionsGetAllCompetitions",
    "GetAllCompetitionsGetAllCompetitionsAllEvents",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisite",
    "GetAllEventPhasesByDiscipline",
    "GetAllEventPhasesByDisciplineGetAllEventPhasesByDiscipline",
    "GetAllEventPhasesByDisciplineGetAllEventPhasesByDisciplineDiscipline",
    "GetAllGoldTourEvents",
    "GetAllGoldTourEventsGetAllGoldTourEvents",
    "GetAllGoldTourEventsGetAllGoldTourEventsEvents",
    "GetAllTimeList",
    "GetAllTimeListGetAllTimeList",
    "GetAllTimeListGetAllTimeListPayload",
    "GetAppearance",
    "GetAppearanceGetAppearance",
    "GetAppearanceGetAppearanceDefaultSponsors",
    "GetAppearanceGetAppearanceDefaultSponsorsDarkBgLogo",
    "GetAppearanceGetAppearanceDefaultSponsorsLightBgLogo",
    "GetAppearanceGetAppearanceFeatureImage",
    "GetAppearanceGetAppearanceLogo",
    "GetAppearanceGetAppearanceSponsors",
    "GetAppearanceGetAppearanceSponsorsDarkBgLogo",
    "GetAppearanceGetAppearanceSponsorsLightBgLogo",
    "GetArticle",
    "GetArticleGetArticle",
    "GetArticleGetArticleLocation",
    "GetArticleGetArticleRelatedArticles",
    "GetArticleGetArticleRelatedArticlesLocation",
    "GetArticleGetArticleRelatedArticlesRelatedArticles",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesLocation",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitions",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPage",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitors",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedDiscipline",
    "GetArticleGetArticleRelatedArticlesRelatedMedia",
    "GetArticleGetArticleRelatedCompetitions",
    "GetArticleGetArticleRelatedCompetitionsLastEvent",
    "GetArticleGetArticleRelatedCompetitionsLastEventCircuits",
    "GetArticleGetArticleRelatedCompetitionsLastEventPage",
    "GetArticleGetArticleRelatedCompetitionsNextEvent",
    "GetArticleGetArticleRelatedCompetitionsNextEventCircuits",
    "GetArticleGetArticleRelatedCompetitionsNextEventPage",
    "GetArticleGetArticleRelatedCompetitionsPage",
    "GetArticleGetArticleRelatedCompetitionsPageCampaign",
    "GetArticleGetArticleRelatedCompetitionsPageContentModules",
    "GetArticleGetArticleRelatedCompetitionsPageEvent",
    "GetArticleGetArticleRelatedCompetitionsPageMinisite",
    "GetArticleGetArticleRelatedCompetitors",
    "GetArticleGetArticleRelatedCompetitorsRelatedMedia",
    "GetArticleGetArticleRelatedDiscipline",
    "GetArticleGetArticleRelatedMedia",
    "GetArticleLocations",
    "GetArticleLocationsGetArticleLocations",
    "GetArticles",
    "GetArticlesGetArticles",
    "GetArticlesGetArticlesLocation",
    "GetArticlesGetArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesLocation",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesLocation",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedArticlesRelatedMedia",
    "GetArticlesGetArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedCompetitionsLastEvent",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPage",
    "GetArticlesGetArticlesRelatedCompetitionsNextEvent",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPage",
    "GetArticlesGetArticlesRelatedCompetitionsPage",
    "GetArticlesGetArticlesRelatedCompetitionsPageCampaign",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModules",
    "GetArticlesGetArticlesRelatedCompetitionsPageEvent",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisite",
    "GetArticlesGetArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedCompetitorsRelatedMedia",
    "GetArticlesGetArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedMedia",
    "GetAsset",
    "GetAssetGetAsset",
    "GetAssetGetAssetCampaign",
    "GetAssetGetAssetDocument",
    "GetAssetGetAssetFilters",
    "GetAssetGetAssetFiltersType",
    "GetAssetGetAssetFiltersTypeFilters",
    "GetAssetGetAssetThumbnailFeatureImage",
    "GetAssets",
    "GetAssetsDates",
    "GetAssetsDatesGetAssetsDates",
    "GetAssetsGetAssets",
    "GetAssetsGetAssetsCampaign",
    "GetAssetsGetAssetsDocument",
    "GetAssetsGetAssetsFilters",
    "GetAssetsGetAssetsFiltersType",
    "GetAssetsGetAssetsFiltersTypeFilters",
    "GetAssetsGetAssetsThumbnailFeatureImage",
    "GetAssetsTotal",
    "GetAssetsTotalGetAssetsTotal",
    "GetAthlete",
    "GetAthleteGetAthlete",
    "GetAthleteGetAthletePrimaryMedia",
    "GetAthleteProfileAthleteRepresentative",
    "GetAthleteProfileAthleteRepresentativeGetAthleteProfileAthleteRepresentative",
    "GetAthleteRepresentativeAthleteSearch",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearch",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletes",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletesChildren",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchCountries",
    "GetAthleteRepresentativeDirectory",
    "GetAthleteRepresentativeDirectoryGetAthleteRepresentativeDirectory",
    "GetAthleteRepresentativeProfile",
    "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfile",
    "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplist",
    "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplistAthletes",
    "GetAthleteRepresentativeTopList",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopList",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEventTypes",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEvents",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListGenders",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplist",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplistAthletes",
    "GetAthleteResults",
    "GetAthleteResultsGetAthleteResults",
    "GetAthleteResultsGetAthleteResultsTeamMembers",
    "GetBanners",
    "GetBannersGetBanners",
    "GetBannersGetBannersBannerItems",
    "GetBannersGetBannersBannerItemsPrimaryMedia",
    "GetCISCompetitorResDate",
    "GetCISCompetitorResDateGetCISCompetitorResDate",
    "GetCISCompetitorResDateGetCISCompetitorResDateParameters",
    "GetCISCompetitorResDateGetCISCompetitorResDateResultsByDate",
    "GetCISCompetitorResDisp",
    "GetCISCompetitorResDispGetCISCompetitorResDisp",
    "GetCISCompetitorResDispGetCISCompetitorResDispParameters",
    "GetCISCompetitorResDispGetCISCompetitorResDispResultsByDate",
    "GetCISCompetitorResDispGetCISCompetitorResDispResultsByEvent",
    "GetCISCompetitorResDispGetCISCompetitorResDispResultsByEventResults",
    "GetCISSingleCompetitor",
    "GetCISSingleCompetitorGetCISSingleCompetitor",
    "GetCISSingleCompetitorGetCISSingleCompetitorAthleteRepresentative",
    "GetCISSingleCompetitorGetCISSingleCompetitorBasicData",
    "GetCISSingleCompetitorGetCISSingleCompetitorHonours",
    "GetCISSingleCompetitorGetCISSingleCompetitorHonoursResults",
    "GetCISSingleCompetitorGetCISSingleCompetitorPersonalBests",
    "GetCISSingleCompetitorGetCISSingleCompetitorPersonalBestsResults",
    "GetCISSingleCompetitorGetCISSingleCompetitorProgressionOfSeasonsBests",
    "GetCISSingleCompetitorGetCISSingleCompetitorProgressionOfSeasonsBestsResults",
    "GetCISSingleCompetitorGetCISSingleCompetitorResultsByDate",
    "GetCISSingleCompetitorGetCISSingleCompetitorResultsByDateParameters",
    "GetCISSingleCompetitorGetCISSingleCompetitorResultsByDateResultsByDate",
    "GetCISSingleCompetitorGetCISSingleCompetitorResultsByYear",
    "GetCISSingleCompetitorGetCISSingleCompetitorResultsByYearParameters",
    "GetCISSingleCompetitorGetCISSingleCompetitorResultsByYearResultsByEvent",
    "GetCISSingleCompetitorGetCISSingleCompetitorResultsByYearResultsByEventResults",
    "GetCISSingleCompetitorGetCISSingleCompetitorRoadRaceLabelStatus",
    "GetCISSingleCompetitorGetCISSingleCompetitorSeasonsBests",
    "GetCISSingleCompetitorGetCISSingleCompetitorSeasonsBestsParameters",
    "GetCISSingleCompetitorGetCISSingleCompetitorSeasonsBestsResults",
    "GetCISSingleCompetitorGetCISSingleCompetitorWorldRankings",
    "GetCISSingleCompetitorGetCISSingleCompetitorWorldRankingsBest",
    "GetCISSingleCompetitorGetCISSingleCompetitorWorldRankingsCurrent",
    "GetCISSingleCompetitorGetCISSingleCompetitorWorldRankingsParameters",
    "GetCalendarCompetitionResults",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResults",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters",
    "GetCalendarEvents",
    "GetCalendarEventsGetCalendarEvents",
    "GetCalendarEventsGetCalendarEventsOptions",
    "GetCalendarEventsGetCalendarEventsOptionsCompetitionGroups",
    "GetCalendarEventsGetCalendarEventsOptionsCompetitionSubgroups",
    "GetCalendarEventsGetCalendarEventsOptionsDisciplines",
    "GetCalendarEventsGetCalendarEventsOptionsPermitLevels",
    "GetCalendarEventsGetCalendarEventsOptionsRankingCategories",
    "GetCalendarEventsGetCalendarEventsOptionsRegions",
    "GetCalendarEventsGetCalendarEventsOptionsRegionsArea",
    "GetCalendarEventsGetCalendarEventsOptionsRegionsCountry",
    "GetCalendarEventsGetCalendarEventsOptionsRegionsWorld",
    "GetCalendarEventsGetCalendarEventsOptionsSeasons",
    "GetCalendarEventsGetCalendarEventsParameters",
    "GetCalendarEventsGetCalendarEventsResults",
    "GetCalendarEventsGetCalendarEventsResultsUndeterminedCompetitionPeriod",
    "GetCampaign",
    "GetCampaignGetCampaign",
    "GetCampaigns",
    "GetCampaignsGetCampaigns",
    "GetCarousel",
    "GetCarouselGetCarousel",
    "GetCarouselGetCarouselCarouselItems",
    "GetCarouselGetCarouselCarouselItemsPrimaryMedia",
    "GetCarouselGetCarouselMedia",
    "GetChampionshipHighlights",
    "GetChampionshipHighlightsGetChampionshipHighlights",
    "GetChampionshipHighlightsGetChampionshipHighlightsDays",
    "GetChampionshipHighlightsGetChampionshipHighlightsRounds",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecords",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHead",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponents",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlights",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitors",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalists",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecords",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitor",
    "GetChampionshipQualifications",
    "GetChampionshipQualificationsGetChampionshipQualifications",
    "GetChampionshipQualificationsGetChampionshipQualificationsAlternativeEntryStandards",
    "GetChampionshipQualificationsGetChampionshipQualificationsCountries",
    "GetChampionshipQualificationsGetChampionshipQualificationsEvents",
    "GetChampionshipQualificationsGetChampionshipQualificationsQualificationTypes",
    "GetChampionshipQualificationsGetChampionshipQualificationsQualifications",
    "GetCombinedPoints",
    "GetCombinedPointsGetCombinedPoints",
    "GetCombinedPointsGetCombinedPointsAllDisciplines",
    "GetCombinedPointsGetCombinedPointsCompetitors",
    "GetCombinedPointsGetCombinedPointsCompetitorsDisciplines",
    "GetCompetitionOrganiserInfo",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits",
    "GetCompetitor",
    "GetCompetitorAAId",
    "GetCompetitorGetCompetitor",
    "GetCompetitorsLegacyPrimaryMedia",
    "GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia",
    "GetCountries",
    "GetCountriesGetCountries",
    "GetDiscipline",
    "GetDisciplineGetDiscipline",
    "GetDraftedArticle",
    "GetDraftedArticleGetDraftedArticle",
    "GetDraftedArticleGetDraftedArticleContentModules",
    "GetDraftedArticleGetDraftedArticleContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleEvent",
    "GetDraftedArticleGetDraftedArticleEventCircuits",
    "GetDraftedArticleGetDraftedArticleEventPage",
    "GetDraftedArticleGetDraftedArticleEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleEventPageEvent",
    "GetDraftedArticleGetDraftedArticleEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsors",
    "GetEvent",
    "GetEventBrokenRecords",
    "GetEventBrokenRecordsGetEventBrokenRecords",
    "GetEventBrokenRecordsGetEventBrokenRecordsDiscipline",
    "GetEventCircuitStandings",
    "GetEventCircuitStandingsGetEventCircuitStandings",
    "GetEventCircuitStandingsGetEventCircuitStandingsParameters",
    "GetEventCircuitStandingsGetEventCircuitStandingsStandings",
    "GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntries",
    "GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntriesResults",
    "GetEventGetEvent",
    "GetEventGetEventCircuits",
    "GetEventGetEventRelatedMedia",
    "GetEventLeadingStandings",
    "GetEventLeadingStandingsGetEventLeadingStandings",
    "GetEventLeadingStandingsGetEventLeadingStandingsDiscipline",
    "GetEventPhaseByDiscipline",
    "GetEventPhaseByDisciplineGetEventPhaseByDiscipline",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineDiscipline",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineDocuments",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummary",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummaryTeamMembers",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnits",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResults",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResultsTeamMembers",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeries",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeriesAttempts",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSplits",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlist",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlistTeamMembers",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandings",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandingsTeamMembers",
    "GetEventPhaseResultDetail",
    "GetEventPhaseResultDetailGetEventPhaseResultDetail",
    "GetEventPhaseResultDetailGetEventPhaseResultDetailDiscipline",
    "GetEventPhaseResultDetailGetEventPhaseResultDetailResult",
    "GetEventPhaseResultDetailGetEventPhaseResultDetailResultDiscipline",
    "GetEventPhaseResults",
    "GetEventPhaseResultsGetEventPhaseResults",
    "GetEventPhaseResultsGetEventPhaseResultsDiscipline",
    "GetEventPhaseResultsGetEventPhaseResultsResult",
    "GetEventPhaseResultsGetEventPhaseResultsResultDiscipline",
    "GetEventPhases",
    "GetEventPhasesGetEventPhases",
    "GetEventPhasesGetEventPhasesDiscipline",
    "GetEventTeamStandingDetails",
    "GetEventTeamStandingDetailsGetEventTeamStandingDetails",
    "GetEventTeamStandingDetailsGetEventTeamStandingDetailsCompetitor",
    "GetEventTeamStandingDetailsGetEventTeamStandingDetailsDiscipline",
    "GetEventTeamStandings",
    "GetEventTeamStandingsGetEventTeamStandings",
    "GetEventTimetable",
    "GetEventTimetableGetEventTimetable",
    "GetEventTimetableGetEventTimetableDiscipline",
    "GetEvents",
    "GetEventsGetEvents",
    "GetEventsGetEventsCircuits",
    "GetEventsGetEventsPage",
    "GetEventsGetEventsPageCampaign",
    "GetEventsGetEventsPageContentModules",
    "GetEventsGetEventsPageContentModulesBanners",
    "GetEventsGetEventsPageContentModulesFeatureLinks",
    "GetEventsGetEventsPageContentModulesLifestyleLinks",
    "GetEventsGetEventsPageContentModulesLocations",
    "GetEventsGetEventsPageContentModulesMinisite",
    "GetEventsGetEventsPageContentModulesMinisitePage",
    "GetEventsGetEventsPageContentModulesRelatedArticles",
    "GetEventsGetEventsPageContentModulesRelatedCompetitors",
    "GetEventsGetEventsPageContentModulesRelatedDiscipline",
    "GetEventsGetEventsPageContentModulesRelatedEvents",
    "GetEventsGetEventsPageContentModulesRelatedMedia",
    "GetEventsGetEventsPageContentModulesRelatedVideo",
    "GetEventsGetEventsPageContentModulesRelatedVideos",
    "GetEventsGetEventsPageContentModulesSections",
    "GetEventsGetEventsPageContentModulesSlides",
    "GetEventsGetEventsPageContentModulesVideos",
    "GetEventsGetEventsPageEvent",
    "GetEventsGetEventsPageEventCircuits",
    "GetEventsGetEventsPageEventPage",
    "GetEventsGetEventsPageMinisite",
    "GetEventsGetEventsPageMinisiteDefaultSponsors",
    "GetEventsGetEventsPageMinisiteFeatureImage",
    "GetEventsGetEventsPageMinisiteLogo",
    "GetEventsGetEventsPageMinisiteSponsors",
    "GetFilterTypes",
    "GetFilterTypesGetFilterTypes",
    "GetFilterTypesGetFilterTypesFilters",
    "GetFilterTypesGetFilterTypesFiltersType",
    "GetFilterTypesGetFilterTypesFiltersTypeFilters",
    "GetFlashInterviews",
    "GetFlashInterviewsGetFlashInterviews",
    "GetFlashInterviewsGetFlashInterviewsInterviews",
    "GetHeroAthletesCarousel",
    "GetHeroAthletesCarouselGetHeroAthletesCarousel",
    "GetHeroAthletesCarouselGetHeroAthletesCarouselRelatedMedia",
    "GetLatestQualifiedCompetitors",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitors",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsColumns",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualifications",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitor",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitorTeamMembers",
    "GetLatestRecords",
    "GetLatestRecordsGetLatestRecords",
    "GetLatestRecordsGetLatestRecordsRecords",
    "GetLatestRecordsGetLatestRecordsRecordsCompetitor",
    "GetLatestRecordsGetLatestRecordsRecordsCompetitorTeamMembers",
    "GetLeadingAthletes",
    "GetLeadingAthletesGetLeadingAthletes",
    "GetLeadingAthletesGetLeadingAthletesEventResults",
    "GetLeadingAthletesGetLeadingAthletesEventResultsResults",
    "GetLeadingAthletesGetLeadingAthletesEventResultsResultsCompetitor",
    "GetLeadingAthletesGetLeadingAthletesEventResultsResultsPrimaryMedia",
    "GetLiveBlogPosts",
    "GetLiveBlogPostsGetLiveBlogPosts",
    "GetLiveCombinedSummaryDetails",
    "GetLiveCombinedSummaryDetailsGetLiveCombinedSummaryDetails",
    "GetLivePhaseSummary",
    "GetLivePhaseSummaryGetLivePhaseSummary",
    "GetLiveResult",
    "GetLiveResultGetLiveResult",
    "GetLiveResultGetLiveResultTeamMembers",
    "GetMedal",
    "GetMedalDetails",
    "GetMedalDetailsGetMedalDetails",
    "GetMedalGetMedal",
    "GetMedals",
    "GetMedalsGetMedals",
    "GetMedalsGetMedalsCountry",
    "GetMedia",
    "GetMediaGetMedia",
    "GetMedias",
    "GetMediasGetMedias",
    "GetMetaData",
    "GetMetaDataGetMetaData",
    "GetMetaDataGetMetaDataCountryCodes",
    "GetMetaDataGetMetaDataDisciplineCodes",
    "GetMinisiteCalendarEvents",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEvents",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptions",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionGroups",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionSubgroups",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsDisciplines",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsPermitLevels",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRankingCategories",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegions",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsArea",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsCountry",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsWorld",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsSeasons",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsParameters",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsResults",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsResultsUndeterminedCompetitionPeriod",
    "GetNewArticle",
    "GetNewArticleGetNewArticle",
    "GetNewArticleGetNewArticleContentModules",
    "GetNewArticleGetNewArticleContentModulesLocations",
    "GetNewArticleGetNewArticleContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleEvent",
    "GetNewArticleGetNewArticleEventCircuits",
    "GetNewArticleGetNewArticleEventPage",
    "GetNewArticleGetNewArticleEventPageCampaign",
    "GetNewArticleGetNewArticleEventPageContentModules",
    "GetNewArticleGetNewArticleEventPageEvent",
    "GetNewArticleGetNewArticleEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageCampaign",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModules",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedEvents",
    "GetNewArticleGetNewArticleRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedEventsPageCampaign",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModules",
    "GetNewArticleGetNewArticleRelatedEventsPageEvent",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisite",
    "GetNewArticleGetNewArticleRelatedLinks",
    "GetNewArticleGetNewArticleRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedMinisitePagesCampaign",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSections",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventCircuits",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsors",
    "GetNewArticles",
    "GetNewArticlesGetNewArticles",
    "GetNewArticlesGetNewArticlesContentModules",
    "GetNewArticlesGetNewArticlesContentModulesLocations",
    "GetNewArticlesGetNewArticlesContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesEvent",
    "GetNewArticlesGetNewArticlesEventCircuits",
    "GetNewArticlesGetNewArticlesEventPage",
    "GetNewArticlesGetNewArticlesEventPageCampaign",
    "GetNewArticlesGetNewArticlesEventPageContentModules",
    "GetNewArticlesGetNewArticlesEventPageEvent",
    "GetNewArticlesGetNewArticlesEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesCampaign",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetNewMedias",
    "GetNewMediasGetNewMedias",
    "GetNewsTicker",
    "GetNewsTickerGetNewsTicker",
    "GetOnThisDay",
    "GetOnThisDayGetOnThisDay",
    "GetOnThisDayGetOnThisDayResults",
    "GetPage",
    "GetPageGetPage",
    "GetPageGetPageCampaign",
    "GetPageGetPageContentModules",
    "GetPageGetPageContentModulesBanners",
    "GetPageGetPageContentModulesBannersPage",
    "GetPageGetPageContentModulesFeatureLinks",
    "GetPageGetPageContentModulesLifestyleLinks",
    "GetPageGetPageContentModulesLocations",
    "GetPageGetPageContentModulesLocationsLocation",
    "GetPageGetPageContentModulesMinisite",
    "GetPageGetPageContentModulesMinisiteDefaultSponsors",
    "GetPageGetPageContentModulesMinisiteFeatureImage",
    "GetPageGetPageContentModulesMinisiteLogo",
    "GetPageGetPageContentModulesMinisitePage",
    "GetPageGetPageContentModulesMinisitePageCampaign",
    "GetPageGetPageContentModulesMinisitePageContentModules",
    "GetPageGetPageContentModulesMinisitePageEvent",
    "GetPageGetPageContentModulesMinisitePageMinisite",
    "GetPageGetPageContentModulesMinisiteSponsors",
    "GetPageGetPageContentModulesRelatedArticles",
    "GetPageGetPageContentModulesRelatedArticlesContentModules",
    "GetPageGetPageContentModulesRelatedArticlesEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticles",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEvents",
    "GetPageGetPageContentModulesRelatedArticlesRelatedLinks",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMedia",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetPageGetPageContentModulesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetPageGetPageContentModulesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedEvents",
    "GetPageGetPageContentModulesRelatedEventsCircuits",
    "GetPageGetPageContentModulesRelatedEventsPage",
    "GetPageGetPageContentModulesRelatedMedia",
    "GetPageGetPageContentModulesRelatedVideo",
    "GetPageGetPageContentModulesRelatedVideos",
    "GetPageGetPageContentModulesSections",
    "GetPageGetPageContentModulesSectionsLinks",
    "GetPageGetPageContentModulesSlides",
    "GetPageGetPageContentModulesVideos",
    "GetPageGetPageContentModulesVideosThumbnailImage",
    "GetPageGetPageEvent",
    "GetPageGetPageEventCircuits",
    "GetPageGetPageEventPage",
    "GetPageGetPageEventPageCampaign",
    "GetPageGetPageEventPageContentModules",
    "GetPageGetPageEventPageEvent",
    "GetPageGetPageEventPageMinisite",
    "GetPageGetPageMinisite",
    "GetPageGetPageMinisiteDefaultSponsors",
    "GetPageGetPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetPageGetPageMinisiteDefaultSponsorsLightBgLogo",
    "GetPageGetPageMinisiteFeatureImage",
    "GetPageGetPageMinisiteLogo",
    "GetPageGetPageMinisiteSponsors",
    "GetPageGetPageMinisiteSponsorsDarkBgLogo",
    "GetPageGetPageMinisiteSponsorsLightBgLogo",
    "GetPhases",
    "GetPhasesGetPhases",
    "GetPhasesGetPhasesUnits",
    "GetPlacingTable",
    "GetPlacingTableDetails",
    "GetPlacingTableDetailsGetPlacingTableDetails",
    "GetPlacingTableGetPlacingTable",
    "GetPreChampionshipHighlights",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlights",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEvents",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeaders",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampions",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeaders",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembers",
    "GetRandomWorldRankingDiscipline",
    "GetRandomWorldRankingDisciplineGetRandomWorldRankingDiscipline",
    "GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineQuery",
    "GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineRankings",
    "GetRankingGroups",
    "GetRankingGroupsGetRankingGroups",
    "GetRankingGroupsGetRankingGroupsEvents",
    "GetRankingScoreCalculation",
    "GetRankingScoreCalculationGetRankingScoreCalculation",
    "GetRankingScoreCalculationGetRankingScoreCalculationResults",
    "GetRecentResults",
    "GetRecentResultsGetRecentResults",
    "GetRecentResultsGetRecentResultsResults",
    "GetRecentResultsGetRecentResultsResultsEvent",
    "GetRecentResultsGetRecentResultsResultsEventCircuits",
    "GetRecentResultsGetRecentResultsResultsEventPage",
    "GetRecordsByCategory",
    "GetRecordsByCategoryGetRecordsByCategory",
    "GetRecordsByCategoryGetRecordsByCategoryCompetitor",
    "GetRecordsDisciplines",
    "GetRecordsDisciplinesGetRecordsDisciplines",
    "GetResultInfo",
    "GetResultInfoGetResultInfo",
    "GetSingleCompetitor",
    "GetSingleCompetitorAllTimePersonalTop10",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Disciplines",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Parameters",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Results",
    "GetSingleCompetitorGetSingleCompetitor",
    "GetSingleCompetitorGetSingleCompetitorAthleteRepresentative",
    "GetSingleCompetitorGetSingleCompetitorBasicData",
    "GetSingleCompetitorGetSingleCompetitorBasicDataPrimaryMedia",
    "GetSingleCompetitorGetSingleCompetitorHonours",
    "GetSingleCompetitorGetSingleCompetitorHonoursResults",
    "GetSingleCompetitorGetSingleCompetitorPersonalBests",
    "GetSingleCompetitorGetSingleCompetitorPersonalBestsResults",
    "GetSingleCompetitorGetSingleCompetitorPrimaryMedia",
    "GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBests",
    "GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBestsResults",
    "GetSingleCompetitorGetSingleCompetitorResultsByDate",
    "GetSingleCompetitorGetSingleCompetitorResultsByDateParameters",
    "GetSingleCompetitorGetSingleCompetitorResultsByDateResultsByDate",
    "GetSingleCompetitorGetSingleCompetitorResultsByYear",
    "GetSingleCompetitorGetSingleCompetitorResultsByYearParameters",
    "GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEvent",
    "GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEventResults",
    "GetSingleCompetitorGetSingleCompetitorSeasonsBests",
    "GetSingleCompetitorGetSingleCompetitorSeasonsBestsParameters",
    "GetSingleCompetitorGetSingleCompetitorSeasonsBestsResults",
    "GetSingleCompetitorGetSingleCompetitorWorldRankings",
    "GetSingleCompetitorGetSingleCompetitorWorldRankingsBest",
    "GetSingleCompetitorGetSingleCompetitorWorldRankingsCurrent",
    "GetSingleCompetitorGetSingleCompetitorWorldRankingsParameters",
    "GetSingleCompetitorHonourSummary",
    "GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary",
    "GetSingleCompetitorMajorChampionships",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionships",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsParameters",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResults",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResultsResults",
    "GetSingleCompetitorResultsByLimit",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimit",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitDisciplines",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitParameters",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitResults",
    "GetSingleCompetitorResultsDate",
    "GetSingleCompetitorResultsDateGetSingleCompetitorResultsDate",
    "GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateParameters",
    "GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateResultsByDate",
    "GetSingleCompetitorResultsDiscipline",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDiscipline",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineParameters",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByDate",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEvent",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEventResults",
    "GetSingleCompetitorSeasonBests",
    "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBests",
    "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsParameters",
    "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsResults",
    "GetSingleCompetitorWinningStreak",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreak",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakDisciplineOptions",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakParameters",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaks",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaksResults",
    "GetSocialCarousel",
    "GetSocialCarouselGetSocialCarousel",
    "GetSocialCarouselGetSocialCarouselPrimaryMedia",
    "GetSpikes",
    "GetSpikesGetSpikes",
    "GetSpikesGetSpikesPrimaryMedia",
    "GetSpikesGetSpikesRelatedTags",
    "GetTeamResults",
    "GetTeamResultsGetTeamResults",
    "GetTeamResultsGetTeamResultsTeamMembers",
    "GetTeamScoring",
    "GetTeamScoringGetTeamScoring",
    "GetTeamScoringGetTeamScoringAthlete",
    "GetTeamScoringGetTeamScoringAthleteDetail",
    "GetTopList",
    "GetTopListGetTopList",
    "GetTopListGetTopListPayload",
    "GetTopListsDisciplines",
    "GetTopListsDisciplinesGetTopListsDisciplines",
    "GetTopRankings",
    "GetTopRankingsGetTopRankings",
    "GetTopRankingsGetTopRankingsRankings",
    "GetTopRankingsGetTopRankingsRankingsPrimaryMedia",
    "GetTrendingAthletes",
    "GetTrendingAthletesGetTrendingAthletes",
    "GetTrendingAthletesGetTrendingAthletesAthletesList",
    "GetTrendingAthletesGetTrendingAthletesAthletesListPrimaryMedia",
    "GetTrendingAthletesGetTrendingAthletesPrimaryMedia",
    "GetUpcomingCompetitions",
    "GetUpcomingCompetitionsGetUpcomingCompetitions",
    "GetUpcomingCompetitionsGetUpcomingCompetitionsCompetitions",
    "GetUser",
    "GetUserGetUser",
    "GetUserGetUserSettings",
    "GetUsersVotes",
    "GetUsersVotesGetUsersVotes",
    "GetVerification",
    "GetVerificationGetVerification",
    "GetVideoById",
    "GetVideoByIdGetVideoById",
    "GetVideoList",
    "GetVideoListGetVideoList",
    "GetVideoPlaylist",
    "GetVideoPlaylistGetVideoPlaylist",
    "GetVideosTotalNumber",
    "GetVideosTotalNumberGetVideosTotalNumber",
    "GetVocabulary",
    "GetVocabularyGetVocabulary",
    "GetVoteOptions",
    "GetVoteOptionsGetVoteOptions",
    "GetWawCompetition",
    "GetWawCompetitionEventsOrganizerDetails",
    "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails",
    "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails",
    "GetWawCompetitionGetWawCompetition",
    "GetWawCompetitionGetWawCompetitionLastEvent",
    "GetWawCompetitionGetWawCompetitionLastEventCircuits",
    "GetWawCompetitionGetWawCompetitionLastEventPage",
    "GetWawCompetitionGetWawCompetitionLastEventPageCampaign",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModules",
    "GetWawCompetitionGetWawCompetitionLastEventPageEvent",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisite",
    "GetWawCompetitionGetWawCompetitionNextEvent",
    "GetWawCompetitionGetWawCompetitionNextEventCircuits",
    "GetWawCompetitionGetWawCompetitionNextEventPage",
    "GetWawCompetitionGetWawCompetitionNextEventPageCampaign",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModules",
    "GetWawCompetitionGetWawCompetitionNextEventPageEvent",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisite",
    "GetWawCompetitionGetWawCompetitionPage",
    "GetWawCompetitionGetWawCompetitionPageCampaign",
    "GetWawCompetitionGetWawCompetitionPageContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesBanners",
    "GetWawCompetitionGetWawCompetitionPageContentModulesFeatureLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesLifestyleLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesLocations",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisite",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideos",
    "GetWawCompetitionGetWawCompetitionPageContentModulesSections",
    "GetWawCompetitionGetWawCompetitionPageContentModulesSlides",
    "GetWawCompetitionGetWawCompetitionPageContentModulesVideos",
    "GetWawCompetitionGetWawCompetitionPageEvent",
    "GetWawCompetitionGetWawCompetitionPageEventCircuits",
    "GetWawCompetitionGetWawCompetitionPageEventPage",
    "GetWawCompetitionGetWawCompetitionPageMinisite",
    "GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionPageMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionPageMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionPageMinisiteSponsors",
    "GetWawEvent",
    "GetWawEventCountryList",
    "GetWawEventCountryListGetWawEventCountryList",
    "GetWawEventCountryListGetWawEventCountryListCountries",
    "GetWawEventGetWawEvent",
    "GetWawEventGetWawEventCircuits",
    "GetWawEventGetWawEventPage",
    "GetWawEventGetWawEventPageCampaign",
    "GetWawEventGetWawEventPageContentModules",
    "GetWawEventGetWawEventPageContentModulesBanners",
    "GetWawEventGetWawEventPageContentModulesFeatureLinks",
    "GetWawEventGetWawEventPageContentModulesLifestyleLinks",
    "GetWawEventGetWawEventPageContentModulesLocations",
    "GetWawEventGetWawEventPageContentModulesMinisite",
    "GetWawEventGetWawEventPageContentModulesMinisitePage",
    "GetWawEventGetWawEventPageContentModulesRelatedArticles",
    "GetWawEventGetWawEventPageContentModulesRelatedCompetitors",
    "GetWawEventGetWawEventPageContentModulesRelatedDiscipline",
    "GetWawEventGetWawEventPageContentModulesRelatedEvents",
    "GetWawEventGetWawEventPageContentModulesRelatedMedia",
    "GetWawEventGetWawEventPageContentModulesRelatedVideo",
    "GetWawEventGetWawEventPageContentModulesRelatedVideos",
    "GetWawEventGetWawEventPageContentModulesSections",
    "GetWawEventGetWawEventPageContentModulesSlides",
    "GetWawEventGetWawEventPageContentModulesVideos",
    "GetWawEventGetWawEventPageEvent",
    "GetWawEventGetWawEventPageEventCircuits",
    "GetWawEventGetWawEventPageEventPage",
    "GetWawEventGetWawEventPageMinisite",
    "GetWawEventGetWawEventPageMinisiteDefaultSponsors",
    "GetWawEventGetWawEventPageMinisiteFeatureImage",
    "GetWawEventGetWawEventPageMinisiteLogo",
    "GetWawEventGetWawEventPageMinisiteSponsors",
    "GetWawMedalDetails",
    "GetWawMedalDetailsGetWawMedalDetails",
    "GetWawMedalDetailsGetWawMedalDetailsCompetitor",
    "GetWawMedalDetailsGetWawMedalDetailsDiscipline",
    "GetWawMenu",
    "GetWawMenuGetWawMenu",
    "GetWawMenuGetWawMenuEvent",
    "GetWawMenuGetWawMenuEventCircuits",
    "GetWawMenuGetWawMenuEventPage",
    "GetWawMenuGetWawMenuEventPageCampaign",
    "GetWawMenuGetWawMenuEventPageContentModules",
    "GetWawMenuGetWawMenuEventPageEvent",
    "GetWawMenuGetWawMenuEventPageMinisite",
    "GetWawMenuGetWawMenuItems",
    "GetWawMenuGetWawMenuItemsItems",
    "GetWawMenuGetWawMenuItemsItemsItems",
    "GetWawMenuGetWawMenuItemsItemsPage",
    "GetWawMenuGetWawMenuItemsPage",
    "GetWawMenuGetWawMenuItemsPageCampaign",
    "GetWawMenuGetWawMenuItemsPageContentModules",
    "GetWawMenuGetWawMenuItemsPageEvent",
    "GetWawMenuGetWawMenuItemsPageMinisite",
    "GetWawPlacingTableDetails",
    "GetWawPlacingTableDetailsGetWawPlacingTableDetails",
    "GetWawPlacingTableDetailsGetWawPlacingTableDetailsCompetitor",
    "GetWawPlacingTableDetailsGetWawPlacingTableDetailsDiscipline",
    "GetWawPlacingTables",
    "GetWawPlacingTablesGetWawPlacingTables",
    "GetWorldLeadingCompetitors",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitors",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResults",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResults",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitor",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsPrimaryMedia",
    "GetWorldRanking",
    "GetWorldRankingGetWorldRanking",
    "GetWorldRankings",
    "GetWorldRankingsChanges",
    "GetWorldRankingsChangesGetWorldRankingsChanges",
    "GetWorldRankingsChangesGetWorldRankingsChangesChanges",
    "GetWorldRankingsGetWorldRankings",
    "GetWorldRankingsGetWorldRankingsParameters",
    "GetWorldRankingsGetWorldRankingsRankings",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQlClientInvalidResponseError",
    "HeadToHead",
    "HeadToHeadHeadToHead",
    "HeadToHeadHeadToHeadDisciplines",
    "HeadToHeadHeadToHeadOpponents",
    "HeadToHeadHeadToHeadParameters",
    "HeadToHeadHeadToHeadResults",
    "HeadToHeadHeadToHeadResultsResults",
    "LiveCombinedSummaryDetailInput",
    "LivePhaseSummaryInput",
    "LivePhaseSummaryQuery",
    "LiveResultInput",
    "LiveResultTeamMemberInput",
    "MedalDetailInput",
    "MedalInput",
    "MedalMutationInput",
    "MetaDataTypes",
    "MyAthletes",
    "MyAthletesMyAthletes",
    "MyAthletesMyAthletesPrimaryMedia",
    "OrderByEnum",
    "OrderByLiveBlogPostEnum",
    "OrderByNewArticleEnum",
    "OrderDirectionEnum",
    "PhaseInput",
    "PhaseQueryInput",
    "PlacingTableDetailInput",
    "PlacingTableInput",
    "PlacingTableOrderBy",
    "PreviousMedalQuery",
    "PreviousMedalists",
    "PreviousMedalistsPreviousMedalists",
    "RecordsByEvent",
    "RecordsByEventRecordsByEvent",
    "RecordsByEventRecordsByEventCompetitor",
    "RelatedCompetitionEnum",
    "ResultsByAthlete",
    "ResultsByAthleteResultsByAthlete",
    "ResultsByAthleteResultsByAthleteParameters",
    "ResultsByAthleteResultsByAthleteResults",
    "ResultsByAthleteResultsByAthleteResultsAthlete",
    "SearchAthletes",
    "SearchAthletesSearchAthletes",
    "SearchAthletesSearchAthletesCompetitionEntries",
    "SearchAthletesSearchAthletesCompetitionEntriesDiscipline",
    "SearchAthletesSearchAthletesDisciplines",
    "SearchAthletesSearchAthletesPrimaryMedia",
    "SearchCompetitors",
    "SearchCompetitorsSearchCompetitors",
    "TeamProfile",
    "TeamProfileTeamProfile",
    "TeamProfileTeamProfilePersonalBestInfo",
    "TeamProfileTeamProfilePersonalBests",
    "TeamProfileTeamProfilePersonalBestsDiscipline",
    "TeamProfileTeamProfilePersonalHonour",
    "TeamProfileTeamProfilePersonalHonourDiscipline",
    "TeamProfileTeamProfilePersonalHonourInfo",
    "TeamQuery",
    "TeamScoringInput",
    "TeamStandingOrderBy",
    "TeamStandings",
    "TeamStandingsInput",
    "TeamStandingsTeamStandings",
    "TeamStandingsTeamStandingsRelatedAthlete",
    "TeamStandingsTeamStandingsRelatedAthleteDetail",
    "UnitInput",
    "VerifyCaptchaToken",
    "VerifyCaptchaTokenVerifyCaptchaToken",
    "VerifyHCaptchaToken",
    "VerifyHCaptchaTokenVerifyHCaptchaToken",
    "WorldAthletics",
    "eventPhaseOrderByEnum",
    "medalsOrderByEnum",
]
